pub type RawCursorOf<T> = BoundedVec<u8, <T as Config>::CursorMaxLen>;Expand description
Convenience alias for the raw inner cursor of a migration.
Aliased Type
pub struct RawCursorOf<T>(/* private fields */);pub type RawCursorOf<T> = BoundedVec<u8, <T as Config>::CursorMaxLen>;Convenience alias for the raw inner cursor of a migration.
pub struct RawCursorOf<T>(/* private fields */);